@@ -199,10 +199,9 @@ class DebugTraceTest(CoverageTest):
         out_text = self.f1_debug_output(["sys"])
         tracer_line = re_line(r"CTracer:", out_text).strip()
         if testenv.C_TRACER or testenv.SYS_MON:
-            expected = "CTracer: available"
+            assert tracer_line.startswith("CTracer: available from ")
         else:
-            expected = "CTracer: unavailable"
-        assert expected == tracer_line
+            assert tracer_line == "CTracer: unavailable"
 
     def test_debug_pybehave(self) -> None:
         out_text = self.f1_debug_output(["pybehave"])
@@ -269,14 +268,14 @@ class DebugOutputTest(CoverageTest):
         self.set_environ("COVERAGE_DEBUG_FILE", "debug.out")
         self.debug_sys()
         assert ("", "") == self.stdouterr()
-        with open("debug.out") as f:
+        with open("debug.out", encoding="utf-8") as f:
             assert_good_debug_sys(f.read())
 
     def test_config_file(self) -> None:
         self.make_file(".coveragerc", "[run]\ndebug_file = lotsa_info.txt")
         self.debug_sys()
         assert ("", "") == self.stdouterr()
-        with open("lotsa_info.txt") as f:
+        with open("lotsa_info.txt", encoding="utf-8") as f:
             assert_good_debug_sys(f.read())
 
     def test_stdout_alias(self) -> None:
